VorbisCommentBlock class

Vorbis Comment or called Xiph Comment

Constructors

VorbisCommentBlock(FlacMetaBlock _flacMetaBlock)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAlbum() String?
getAlbumArtist() String?
getArtist() String?
getCD() String?
getComment() String?
getEncoder() String?
getGenre() String?
getLyric() String?
getTitle() String?
getTrack() String?
getYear() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → void
setAlbum(String? album) → void
setAlbumArtist(String? albumArtist) → void
setArtist(String? artist) → void
setCD(String? cd) → void
setComment(String? comment) → void
setEncoder(String? encoder) → void
setGenre(String? genre) → void
setLyric(String? lyric) → void
setTitle(String? title) → void
setTrack(String? track) → void
setYear(String? year) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited